aboutsummaryrefslogtreecommitdiff
path: root/include/aoapplication.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/aoapplication.h')
-rw-r--r--include/aoapplication.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/aoapplication.h b/include/aoapplication.h
index 9fe1d400..8b248ccc 100644
--- a/include/aoapplication.h
+++ b/include/aoapplication.h
@@ -229,8 +229,8 @@ public:
// Current wait time between messages for the queue system
int stay_time();
- // Returns the letter display speed during text scrawl in in-character messages
- int get_text_scrawl();
+ // Returns the letter display speed during text crawl in in-character messages
+ int get_text_crawl();
// Returns Minimum amount of time (in miliseconds) that must pass before the next Enter key press will send your IC message. (new behaviour)
int get_chat_ratelimit();